@@ -34,12 +34,12 @@ def get_registration():
 
 @lru_cache()
 def get_helper(
-        user: str,
-        password: str,
-        host: str,
-        port: int,
-        database: str,
-        schema_name: str,
+    user: str,
+    password: str,
+    host: str,
+    port: int,
+    database: str,
+    schema_name: str,
 ):
     return JDBCStoreHelper(
         user=user,
@@ -48,7 +48,7 @@ def get_helper(
         port=port,
         database=database,
         schema_name=schema_name,
-        driver='redshift+psycopg2'
+        driver="redshift+psycopg2",
     )
 
 
@@ -57,7 +57,7 @@ def __connection_string_url(c: ConnectionStringContext) -> str:
 
 
 def __write_fn(
-        r: WriteRequest, res: ResolveResourcePathResponse
+    r: WriteRequest, res: ResolveResourcePathResponse
 ) -> WriteResponse:
     from bakplane.extensions.spark.stores.jdbc import write_fn
 
@@ -70,7 +70,7 @@ def __write_fn(
 
 
 def __read_all_fn(
-        ctx: typing.Any, r: ReadAllRequest, res: ResolveResourcePathResponse
+    ctx: typing.Any, r: ReadAllRequest, res: ResolveResourcePathResponse
 ) -> ReadResponse:
     from bakplane.extensions.spark.stores.jdbc import read_all_fn
 
@@ -84,7 +84,7 @@ def __read_all_fn(
 
 
 def __read_fn(
-        ctx: typing.Any, r: ReadRequest, res: ResolveResourceIntentResponse
+    ctx: typing.Any, r: ReadRequest, res: ResolveResourceIntentResponse
 ) -> ReadResponse:
     from bakplane.extensions.spark.stores.jdbc import read_fn
     from sqlalchemy.dialects import postgresql
